@@ -7,15 +7,14 @@ use strict;
 
 package POSIX::1003::FS;
 use vars '$VERSION';
-$VERSION = '0.99_03';
+$VERSION = '0.99_04';
 
 use base 'POSIX::1003::Module';
 
 # Blocks resp from unistd.h, stdio.h, limits.h
 my @constants;
 my @access = qw/access/;
-my @stat   = qw/stat lstat/;
-my @perms  = qw/mkfifo mknod mkdir lchown
+my @stat   = qw/stat lstat mkfifo mknod mkdir lchown
   S_ISDIR S_ISCHR S_ISBLK S_ISREG S_ISFIFO S_ISLNK S_ISSOCK S_ISWHT
 /;
 my @glob;  # qw/glob fnmatch/;
@@ -31,7 +30,6 @@ sub S_ISWHT($)  { ($_[0] & S_IFMT()) == S_IFWHT()}  # FreeBSD
 
 # POSIX.xs defines L_ctermid L_cuserid L_tmpname: useless!
 
-# Blocks resp from sys/stat.h, unistd.h, utime.h, sys/types
 my @functions = qw/
  mkfifo mknod stat lstat rename
  access lchown
@@ -48,14 +46,13 @@ our %EXPORT_TAGS =
  , stat      => \@stat
  , glob      => \@glob
  , tables    => [ qw/%access %stat/ ]
- , perms     => \@perms
  );
 
-my ($fsys, %access, %stat, %glob, %perms);
+my ($fsys, %access, %stat, %glob);
 
 BEGIN {
     $fsys = fsys_table;
-    push @constants, grep !/^S_IS/, keys %$fsys;
+    push @constants, keys %$fsys;
 
     # initialize the :access export tag
     push @access, grep /_OK$|MAX/, keys %$fsys;
@@ -64,19 +61,13 @@ BEGIN {
     tie %access,  'POSIX::1003::ReadOnlyTable', \%access_subset;
 
     # initialize the :stat export tag
-    push @stat, grep /^S_/, keys %$fsys;
+    push @stat, grep /^S_I/, keys %$fsys;
     my %stat_subset;
     @stat_subset{@stat} = @{$fsys}{@stat};
     tie %stat, 'POSIX::1003::ReadOnlyTable', \%stat_subset;
 
-    # initialize the :perms export tag
-    push @perms, grep /^S_I[^S]/, keys %$fsys;
-    my %perms_subset;
-    @perms_subset{@perms} = @{$fsys}{@perms};
-    tie %perms, 'POSIX::1003::ReadOnlyTable', \%perms_subset;
- 
     # initialize the :fsys export tag
-    push @glob, grep /^(?:GLOB|FNM)_/, keys %$fsys;
+    push @glob, grep /^(?:GLOB|FNM|WRDE)_/, keys %$fsys;
     my %glob_subset;
     @glob_subset{@glob} = @{$fsys}{@glob};
     tie %glob, 'POSIX::1003::ReadOnlyTable', \%glob_subset;
