@@ -65,3 +65,7 @@
 #undef CACHE_UID
 #undef HAS_ULIMIT
 #undef HAS_GLOB
+#undef HAS_SETGROUPS
+#undef HAS_GETGROUPS
+#undef HAS_FCNTL
+#undef I_SYS_WAIT
